@@ -523,7 +523,7 @@ cleanup:
   g_free (downcase);
   g_free (lookup.state);
   g_free (lookup.tables);
-  dzl_clear_pointer (&lookup.matches, g_hash_table_unref);
+  g_clear_pointer (&lookup.matches, g_hash_table_unref);
 
   return matches;
 }
@@ -539,7 +539,7 @@ dzl_fuzzy_mutable_index_contains (DzlFuzzyMutableIndex *fuzzy,
 
   ar = dzl_fuzzy_mutable_index_match (fuzzy, key, 1);
   ret = (ar != NULL) && (ar->len > 0);
-  dzl_clear_pointer (&ar, g_array_unref);
+  g_clear_pointer (&ar, g_array_unref);
 
   return ret;
 }
@@ -568,7 +568,7 @@ dzl_fuzzy_mutable_index_remove (DzlFuzzyMutableIndex *fuzzy,
         }
     }
 
-  dzl_clear_pointer (&ar, g_array_unref);
+  g_clear_pointer (&ar, g_array_unref);
 }
 
 gchar *
@@ -595,16 +595,21 @@ dzl_fuzzy_highlight (const gchar *str,
 
       if (str_ch == '&')
         {
-          if (0 == strncmp (str, "&amp;", 5))
+          const gchar *entity_end = strchr (str, ';');
+
+          if (entity_end != NULL)
             {
-              str += 4;
-              g_string_append (ret, "&amp;");
-              continue;
-            }
-          else if (0 == strncmp (str, "&apos;", 6))
-            {
-              str += 5;
-              g_string_append (ret, "&apos;");
+              gsize len = entity_end - str;
+
+              if (element_open)
+                {
+                  g_string_append (ret, end);
+                  element_open = FALSE;
+                }
+
+              g_string_append_len (ret, str, len + 1);
+              str += len;
+
               continue;
             }
         }
@@ -618,7 +623,12 @@ dzl_fuzzy_highlight (const gchar *str,
               element_open = TRUE;
             }
 
-          g_string_append_unichar (ret, str_ch);
+          if (str_ch == '<')
+            g_string_append (ret, "&lt;");
+          else if (str_ch == '>')
+            g_string_append (ret, "&gt;");
+          else
+            g_string_append_unichar (ret, str_ch);
 
           /* TODO: We could seek to the next char and append in a batch. */
           match = g_utf8_next_char (match);
@@ -631,7 +641,12 @@ dzl_fuzzy_highlight (const gchar *str,
               element_open = FALSE;
             }
 
-          g_string_append_unichar (ret, str_ch);
+          if (str_ch == '<')
+            g_string_append (ret, "&lt;");
+          else if (str_ch == '>')
+            g_string_append (ret, "&gt;");
+          else
+            g_string_append_unichar (ret, str_ch);
         }
     }
 
